#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "netmon_std.h"
#include "database_common.h"

void free_database_struct( struct db_conn *dbc ) {
	if( dbc->insert_space != NULL ) {
		free( dbc->insert_space );
	}
	free( dbc );
}

int configure_db_settings_from_environemnt( struct db_conn *dbc ) {
	char *user, *pass, *server, *database, *hostname;
	int ret = EXIT_SUCCESS;

	user = getenv( "NETMON_DB_USER" );
	pass = getenv( "NETMON_DB_PASS" );
	database = getenv( "NETMON_DB_DATABASE" );
	server = getenv( "NETMON_DB_SERVER" );
	hostname = getenv( "NETMON_HOSTNAME" );

	if( user == NULL || pass == NULL 
		|| database == NULL  || server == NULL ) {
		return( EXIT_FAILURE );
	}

	strncpy( dbc->user, user, BUFFER );
	strncpy( dbc->password, pass, BUFFER );
	strncpy( dbc->database, database, BUFFER );
	strncpy( dbc->server, server, BUFFER );

	if( hostname == NULL ) {
		if( gethostname( dbc->hostname, BUFFER ) ) {
			/**
			 * cannot find hostname, we have a unnamed
			 * column
			 */
			strncpy( dbc->hostname, "Unknown host - try "
				"setting the environment "
				"NETMON_HOSTNAME", BUFFER );
		}
	}
	else {
		strncpy( dbc->hostname, hostname, BUFFER );
	}

	dbc->user[BUFFER-1] = '\0';
	dbc->password[BUFFER-1] = '\0';
	dbc->database[BUFFER-1] = '\0';
	dbc->server[BUFFER-1] = '\0';
	dbc->hostname[BUFFER-1] = '\0';

	ret = setup_db( dbc );

	return( ret );
}

int is_db_environment_present( struct db_conn *dbc ) {
	int ret = EXIT_FAILURE;
	if( getenv( "NETMONDB" ) ) {
		ret = configure_db_settings_from_environemnt( dbc );

	}
	return( ret );
}

int database_values( struct interface_line *il ) {
	struct db_conn *dbc;

	dbc = (struct db_conn*)malloc( sizeof( struct db_conn ) );

	if( dbc == NULL ) {
		fprintf( stderr, "Not enough memory to allocate "
			"db_conn structure\n" );
		exit( EXIT_FAILURE );
	}
	
	if( is_db_environment_present( dbc ) == EXIT_FAILURE ) {
		fprintf( stderr, "No DB connection setup\n" );
		free( dbc );
		return( EXIT_FAILURE );
	}
	
	return( insert_db_row( dbc, il ) );
}

